==> generator-gulp-angular-0.5.1.tgz: package/app/src/compile.js <==
'use strict';

/* Compile choices in this.model */
module.exports = function () {
  //console.log('before compile', this.props)

  var _ = this._;

  this.angularVersion = this.props.angularVersion;

  this.model = {};

  var angularModules = this.props.angularModules.map(function (module) {
    return module.module;
  });

  var modernizr = {
    name: 'modernizr',
    version: '2.8.x'
  };

  if(this.props.ui.key === 'bootstrap' &&
      this.props.cssPreprocessor.extension !== 'scss') {
    this.props.ui.name = 'bootstrap';
  }

  this.model.bowerDependencies = _.flatten([
    modernizr,
    this.props.jQuery,
    this.props.angularModules,
    this.props.resource,
    this.props.router,
    this.props.ui
  ]);

  this.model.bowerResolutions = _.flatten([
    modernizr,
    this.props.jQuery
  ]);

  this.model.wiredepExclusions = [
    this.props.ui.name
  ];

  this.model.modulesDependencies = _.flatten([
    angularModules,
    this.props.resource.module,
    this.props.router.module
  ]);

  this.model.technologies = [
    'angular', 'browsersync', 'gulp', 'jasmine', 'karma', 'protractor',
    this.props.jQuery.name,
    this.props.ui.key,
    this.props.cssPreprocessor.key
  ].filter(_.isString).filter(function(tech) {
    return tech !== 'default' && tech !== 'css';
  });

  this.model.technologies = _.reject(this.model.technologies, _.isNull);

  this.model.npmDependencies = _.extend({}, this.props.cssPreprocessor.npm);

  this.model.vendorStylesPreprocessed = !( this.props.cssPreprocessor.extension === 'css' ||
      this.props.cssPreprocessor.extension === 'less' && this.props.ui.key === 'foundation' );

  if(this.model.vendorStylesPreprocessed) {
    this.model.cssLinks = ['styles/vendor.css'];
  } else {
    this.model.cssLinks = [];
    if(this.props.ui.key === 'bootstrap') {
      this.model.cssLinks.push('bower_components/bootstrap/dist/css/bootstrap.css');
    } else if(this.props.ui.key === 'foundation') {
      this.model.cssLinks.push('bower_components/foundation/css/foundation.css');
    }
  }

  //console.log('compile bower', this.props, this.model.bowerDependencies);

  //Add version number of Angular for all dependencies which has no version specified
  this.model.bowerDependencies.forEach(function (dependency) {
    if (!_.isString(dependency.version)) {
      dependency.version = this.angularVersion;
    }
  }.bind(this));

  //console.log('after compile', this.model);
};

==> generator-gulp-angular-0.6.0.tgz: package/app/src/compile.js <==
'use strict';

/* Compile choices in this.model */
module.exports = function () {
  //console.log('before compile', this.props)

  var _ = this._;

  this.angularVersion = this.props.angularVersion;

  this.model = {};

  var angularModules = this.props.angularModules.map(function (module) {
    return module.module;
  });

  var modernizr = {
    name: 'modernizr',
    version: '2.8.x'
  };

  if(this.props.ui.key === 'bootstrap' &&
      this.props.cssPreprocessor.extension !== 'scss') {
    this.props.ui.name = 'bootstrap';
  }

  this.model.bowerDependencies = _.flatten([
    modernizr,
    this.props.jQuery,
    this.props.angularModules,
    this.props.resource,
    this.props.router,
    this.props.ui
  ]);

  this.model.bowerResolutions = _.flatten([
    modernizr,
    this.props.jQuery
  ]);

  this.model.wiredepExclusions = [
    this.props.ui.name
  ];

  this.model.modulesDependencies = _.flatten([
    angularModules,
    this.props.resource.module,
    this.props.router.module
  ]);

  this.model.technologies = [
    'angular', 'browsersync', 'gulp', 'jasmine', 'karma', 'protractor',
    this.props.jQuery.name,
    this.props.ui.key,
    this.props.cssPreprocessor.key
  ].filter(_.isString).filter(function(tech) {
    return tech !== 'default' && tech !== 'css';
  });

  this.model.technologies = _.reject(this.model.technologies, _.isNull);

  this.model.npmDependencies = _.extend({}, this.props.cssPreprocessor.npm);

  this.model.vendorStylesPreprocessed = !( this.props.cssPreprocessor.extension === 'css' ||
      this.props.cssPreprocessor.extension === 'less' && this.props.ui.key === 'foundation' );

  if(this.model.vendorStylesPreprocessed) {
    this.model.cssLinks = ['app/main/vendor.css'];
  } else {
    this.model.cssLinks = [];
    if(this.props.ui.key === 'bootstrap') {
      this.model.cssLinks.push('bower_components/bootstrap/dist/css/bootstrap.css');
    } else if(this.props.ui.key === 'foundation') {
      this.model.cssLinks.push('bower_components/foundation/css/foundation.css');
    }
  }

  //console.log('compile bower', this.props, this.model.bowerDependencies);

  //Add version number of Angular for all dependencies which has no version specified
  this.model.bowerDependencies.forEach(function (dependency) {
    if (!_.isString(dependency.version)) {
      dependency.version = this.angularVersion;
    }
  }.bind(this));

  //console.log('after compile', this.model);
};
